@@ -1,24 +1,9 @@
 /*
- * This file is part of the KDE Baloo Project
- * Copyright (C) 2013-2015  Vishesh Handa <vhanda@kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
- *
- */
+    This file is part of the KDE Baloo Project
+    SPDX-FileCopyrightText: 2013-2015 Vishesh Handa <vhanda@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 
 #include <KCrash>
 
@@ -64,11 +49,7 @@ int main(int argc, char** argv)
         migrator.migrate();
     }
 
-    bool firstRun = !QFile::exists(path + "/index");
-
-    // HACK: Until we start using lmdb with robust mutex support. We're just going to remove
-    //       the lock manually in the baloo_file process.
-    QFile::remove(path + "/index-lock");
+    bool firstRun = !QFile::exists(path + QStringLiteral("/index"));
 
     Baloo::Database *db = Baloo::globalDatabaseInstance();
 
@@ -78,8 +59,8 @@ int main(int argc, char** argv)
     if (!db->open(Baloo::Database::CreateDatabase)) {
         // delete old stuff, set to initial run!
         qWarning() << "Failed to create database, removing corrupted database.";
-        QFile::remove(path + "/index");
-        QFile::remove(path + "/index-lock");
+        QFile::remove(path + QStringLiteral("/index"));
+        QFile::remove(path + QStringLiteral("/index-lock"));
         firstRun = true;
 
         // try to create now after cleanup, if still no works => fail
